From b283598a07dfdd4e54f01f514b1bf8ae891b3a1d Mon Sep 17 00:00:00 2001
From: Florian Schaal <florian@schaal-24.de>
Date: Thu, 21 Nov 2013 05:03:47 -0500
Subject: [PATCH] interface/web/dns/dns_wizard.php

---
 interface/web/designer/form_list.php |   78 +++++++++++++++++---------------------
 1 files changed, 35 insertions(+), 43 deletions(-)

diff --git a/interface/web/designer/form_list.php b/interface/web/designer/form_list.php
index c220402..0093275 100644
--- a/interface/web/designer/form_list.php
+++ b/interface/web/designer/form_list.php
@@ -27,71 +27,63 @@
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-require_once('../../lib/config.inc.php');
-require_once('../../lib/app.inc.php');
+require_once '../../lib/config.inc.php';
+require_once '../../lib/app.inc.php';
 
-// Checking permissions for the module
-if(!stristr($_SESSION["s"]["user"]["modules"],$_SESSION["s"]["module"]["name"])) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('designer');
 
 $app->uses('tpl');
 
-$app->tpl->newTemplate("form.tpl.htm");
-$app->tpl->setInclude('content_tpl','templates/form_list.htm');
+$app->tpl->newTemplate('form.tpl.htm');
+$app->tpl->setInclude('content_tpl', 'templates/form_list.htm');
 
-function getinfo($file,$form_file,$bgcolor) {
-	global $conf,$app;
+function getinfo($file, $form_file, $bgcolor) {
 	$module_name = $file;
-	include($conf["rootpath"]."/web/".$file."/form/$form_file");
-	return array( 	'name' => $form["name"],
-					'title' => $form["title"],
-					'description' => $form["description"],
-					'module_name' => $module_name,
-					'bgcolor' => $bgcolor);
-	//unset($form);
+	include ISPC_WEB_PATH."/$file/form/$form_file";
+	return array(  'name' =>        $form['name'],
+		'title' =>       $form['title'],
+		'description' => $form['description'],
+		'module_name' => $module_name,
+		'bgcolor' =>     $bgcolor
+	);
 }
 
 // lese Module aus
-$bgcolor = "#FFFFFF";
+$bgcolor = '#FFFFFF';
 $modules_list = array();
-$handle = @opendir($conf["rootpath"]."/web"); 
-while ($file = @readdir ($handle)) { 
-    if ($file != "." && $file != "..") {
-        if(@is_dir($conf["rootpath"]."/web/".$file)) {
-            if(is_file($conf["rootpath"]."/web/".$file."/lib/module.conf.php") and $file != 'login') {
-				
-				if(@is_dir($conf["rootpath"]."/web/".$file."/form")) {
-					$handle2 = opendir($conf["rootpath"]."/web/".$file."/form");
-					while ($form_file = @readdir ($handle2)) {
-						if (substr($form_file,0,1) != ".") {
-						    //echo $conf["rootpath"]."/web/".$file."/form/$form_file<br>";
-							//include_once($conf["rootpath"]."/web/".$file."/form/$form_file");
+$handle = @opendir(ISPC_WEB_PATH);
+while ($file = @readdir($handle)) {
+	if ($file != '.' && $file != '..') {
+		if(@is_dir(ISPC_WEB_PATH."/$file")) {
+			if(is_file(ISPC_WEB_PATH.'/'.$file.'/lib/module.conf.php') and $file != 'login') {
+				if(@is_dir(ISPC_WEB_PATH."/$file/form")) {
+					$handle2 = opendir(ISPC_WEB_PATH."/$file/form");
+					while ($form_file = @readdir($handle2)) {
+						if (substr($form_file, 0, 1) != ".") {
+							//echo ISPC_ROOT_PATH."/web/".$file."/form/$form_file<br>";
+							//include_once(ISPC_ROOT_PATH."/web/".$file."/form/$form_file");
 							// Farbwechsel
-							$bgcolor = ($bgcolor == "#FFFFFF")?"#EEEEEE":"#FFFFFF";
-				
-							$modules_list[] = getinfo($file,$form_file,$bgcolor);
-							
+							$bgcolor = ($bgcolor == '#FFFFFF') ? '#EEEEEE' : '#FFFFFF';
+							$modules_list[] = getinfo($file, $form_file, $bgcolor);
+
 						}
 					}
 				}
 			}
-        }
+		}
 	}
 }
 
+$app->tpl->setLoop('records', $modules_list);
 
-$app->tpl->setLoop('records',$modules_list);
-
-// loading language file 
-$lng_file = "lib/lang/".$_SESSION["s"]["language"]."_form_list.lng";
-include($lng_file);
+//* load language file
+$lng_file = 'lib/lang/'.$_SESSION['s']['language'].'_form_list.lng';
+include $lng_file;
 $app->tpl->setVar($wb);
 
 $app->tpl_defaults();
 $app->tpl->pparse();
 
 
-
-?>
\ No newline at end of file
+?>

--
Gitblit v1.9.1